#! /usr/bin/env python
__author__ = 'Tser'
__datetime__ = '2020/1/29 22:11'
__project__ = 'PythonProject'
__file__ = 'installer.py'

from xiaobaiinstaller.xiaobaicore import main as xmain

def main():
    xmain()

if __name__ == '__main__':
    main()